@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2003, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -214,11 +214,13 @@ public final class NativePRNG extends SecureRandomSpi {
     }
 
     // constructor, called by the JCA framework
-    public NativePRNG() {
-        super();
+    public NativePRNG(SecureRandomParameters params) {
         if (INSTANCE == null) {
             throw new AssertionError("NativePRNG not available");
         }
+        if (params != null) {
+            throw new IllegalArgumentException("Unsupported params: " + params.getClass());
+        }
     }
 
     // set the seed
@@ -262,11 +264,13 @@ public final class NativePRNG extends SecureRandomSpi {
         }
 
         // constructor, called by the JCA framework
-        public Blocking() {
-            super();
+        public Blocking(SecureRandomParameters params) {
             if (INSTANCE == null) {
                 throw new AssertionError("NativePRNG$Blocking not available");
             }
+            if (params != null) {
+                throw new IllegalArgumentException("Unsupported params: " + params.getClass());
+            }
         }
 
         // set the seed
@@ -311,12 +315,14 @@ public final class NativePRNG extends SecureRandomSpi {
         }
 
         // constructor, called by the JCA framework
-        public NonBlocking() {
-            super();
+        public NonBlocking(SecureRandomParameters params) {
             if (INSTANCE == null) {
                 throw new AssertionError(
                     "NativePRNG$NonBlocking not available");
             }
+            if (params != null) {
+                throw new IllegalArgumentException("Unsupported params: " + params.getClass());
+            }
         }
 
         // set the seed
